@@ -1,5 +1,4 @@
 from netnir.helpers.scaffold.command import CommandScaffold
-from netnir.helpers.common.args import num_workers
 from netnir.helpers import output_writer
 from netnir.plugins.netmiko import netmiko_send_commands
 from nornir.plugins.functions.text import print_result
@@ -17,7 +16,6 @@ class FetchConfig(CommandScaffold):
         :param parser: type obj
         """
         CommandScaffold.parser(parser)
-        num_workers(parser)
 
     def run(self):
         """execute the cli task
@@ -26,7 +24,17 @@ class FetchConfig(CommandScaffold):
         """
 
         self.nr = self._inventory()
-        results = self.nr.run(task=netmiko_send_commands, commands="show running")
+        results = self.nr.run(
+            task=netmiko_send_commands,
+            commands="show running",
+            num_workers=self.args.workers,
+            dry_run=self.args.X,
+            severity_level=self._verbose()["level"],
+            to_console=self._verbose()["to_console"],
+            name="FETCH RUNNING CONFIG",
+        )
         output_writer(nornir_results=results, output_file="running.conf")
 
-        return print_result(results)
+        print_result(result=results, severity_level=self._verbose()["level"])
+
+        return results
