@@ -7,8 +7,10 @@ class CommandScaffold:
         :params args: type object
         """
         from netnir.constants import NR
+        import logging
 
         self.args = args
+        self.logging = logging.getLogger("nornir")
         self.nr = NR
 
     @staticmethod
@@ -17,16 +19,32 @@ class CommandScaffold:
 
         :params parser: type object
         """
-        from netnir.helpers.common.args import filter_host, filter_hosts, filter_group
+        from netnir.helpers.common.args import (
+            filter_host,
+            filter_hosts,
+            filter_group,
+            num_workers,
+            make_changes,
+            verbose,
+        )
 
         filter_host(parser)
         filter_hosts(parser)
         filter_group(parser)
+        num_workers(parser)
+        make_changes(parser)
+        verbose(parser)
 
     def run(self):
         """things to do"""
         return "things to do"
 
+    def _verbose(self):
+        self.logging.setLevel(self.args.verbose)
+        to_console = True if self.args.verbose == "DEBUG" else False
+
+        return {"level": self.logging.level, "to_console": to_console}
+
     def _inventory(self):
         """filter inventory
 
