@@ -1,7 +1,8 @@
 from nornir.core.task import Task, Result
+from typing import Any
 
 
-def inventory_facts(task: Task) -> Result:
+def inventory_facts(task: Task, **kwargs: Any) -> Result:
     """gather inventory facts
 
     :params task: type object
