@@ -1,6 +1,30 @@
 from nornir.core.task import Task, Result
 from netnir.helpers import device_mapper
 from ncclient import manager
+from typing import Any
+
+
+def netconf_capabilities(task: Task, **kwargs: Any) -> Result:
+    """nornir get netconf capabilities
+
+    :params task: type object
+    :returns: nornir result object
+    """
+    device_params = {
+        "host": task.host.hostname,
+        "port": task.host.port or 830,
+        "username": task.host.username,
+        "password": task.host.password,
+        "hostkey_verify": False,
+        "device_params": {
+            "name": device_mapper(os_type=task.host.data["os"], proto="netconf")
+        },
+    }
+
+    with manager.connect(**device_params) as conn:
+        results = [capability for capability in conn.server_capabilities]
+
+    return Result(host=task.host, result=results)
 
 
 def netconf_get_config(
@@ -8,6 +32,7 @@ def netconf_get_config(
     source: str = "running",
     nc_filter: str = None,
     nc_filter_type: str = None,
+    **kwargs: Any
 ) -> Result:
     """nornir netconf get config task
 
